#! /usr/bin/env node
"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _process = _interopRequireDefault(require("process"));

var _path = _interopRequireDefault(require("path"));

var _fs = _interopRequireDefault(require("fs"));

var _commander = _interopRequireDefault(require("commander"));

var _fileclient = _interopRequireWildcard(require("@magic-num/fileclient"));

var _hserver = _interopRequireDefault(require("./hserver"));

var _handle = _interopRequireDefault(require("./handle"));

_commander.default.command('start <dir>').option('-h, --host <host>', 'magic server host', '0.0.0.0').option('-p, --port <port>', 'magic server port', '1211').action(function (dir, cmd) {
  var host = cmd.host,
      port = cmd.port;

  var fileClient = _fileclient.default.fromPath(dir);

  var hserver = new _hserver.default(fileClient, dir, port, host);
  hserver.addHandlers([new _handle.default({
    path: '/api',
    get: function get(req, res) {
      _handle.default.success(fileClient.handlers.map(function (h) {
        return {
          id: h.id,
          name: 'test'
        };
      }), res);
    },
    post: function post(req, res) {
      var data = req.data;
      console.info("\u63D0\u4EA4\u53C2\u6570:".concat(JSON.stringify(data)));

      var nfolder = _path.default.join(folder, data.id);

      if (_fs.default.existsSync(nfolder)) {
        _handle.default.fail({
          error: "".concat(data.id, "\u5DF2\u7ECF\u5B58\u5728\uFF0C\u8BF7\u68C0\u67E5\u540D\u79F0")
        });
      } else {
        _fs.default.mkdirSync(nfolder);

        _fs.default.writeFileSync(_path.default.join(nfolder, 'index.json'), JSON.stringify(data));

        var h = new _fileclient.Handler(data.id);
        fileClient.addHandler(h);

        _handle.default.success(req.data, res);
      }
    }
  }), new _handle.default({
    path: '/mock',
    post: function post(req, res) {
      var data = req.data;
      var uri = data.uri,
          params = data.params;
      var request = {
        uri: uri,
        params: params,
        result: null
      };
      request.createTime = Date.now();
      fileClient.req(uri, {
        params: params
      }).then(function (result) {
        request.result = result;
        request.finishTime = Date.now();
        hserver.requests.enqueue(request);

        _handle.default.success(result, res);
      }, function (err) {
        request.result = result;
        request.finishTime = Date.now();
        hserver.requests.enqueue(request);

        _handle.default.fail(err, res);
      });
    }
  }), new _handle.default({
    path: '/info',
    get: function get(req, res) {
      _handle.default.success(hserver.requests.filter(function (i) {
        return i;
      }), res);
    }
  }), new _handle.default({
    path: '/testsuite',
    get: function get(req, res) {
      _handle.default.success({
        testsuites: Object.keys(fileClient.testsuites),
        selected: fileClient.currentTestSuite && fileClient.currentTestSuite.name
      }, res);
    },
    post: function post(req, res) {
      var data = req.data;
      var _data$testsuite = data.testsuite,
          testsuite = _data$testsuite === void 0 ? null : _data$testsuite,
          _data$clear = data.clear,
          clear = _data$clear === void 0 ? false : _data$clear;

      if (clear) {
        fileClient.setCurrentSuite(null);

        _handle.default.success({
          msg: '操作成功'
        }, res);

        return;
      }

      if (testsuite) {
        try {
          fileClient.setCurrentSuite(testsuite);

          _handle.default.success({
            msg: "\u6210\u529F\u5C06\u5F53\u524Dtestsuite\u66F4\u65B0\u4E3A".concat(testsuite)
          }, res);
        } catch (e) {
          _handle.default.fail(e, res);
        }
      } else {
        _handle.default.fail({
          msg: '找不到testsuite'
        }, res);
      }
    }
  })]);
}).version(_process.default.env.npm_package_version);

_commander.default.parse(_process.default.argv);